<?php

/*
 * LMS version 1.4.5 Persus
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: balancenew.php,v 1.20.2.2 2005/01/01 19:19:47 alec Exp $
 */

$_SESSION['backto'] = $_SERVER['QUERY_STRING'];

$layout['pagetitle'] = "Nowa operacja finansowa";
$SMARTY->assign('operation',$_SESSION['addtype']);
$SMARTY->assign('comment',$_SESSION['addbc']);
$SMARTY->assign('taxvalue', $_SESSION['addbtax']);
$SMARTY->assign('time', $_SESSION['addbt']);
$SMARTY->assign('value', $_SESSION['addbv']);
$SMARTY->assign('users',$LMS->GetUserNames());
$SMARTY->display('balancenew.html');

?>